# squeeze-rest [![Latest Release](https://gitlab.com/OldIronHorse/squeeze-rest/-/badges/release.svg)](https://gitlab.com/OldIronHorse/squeeze-rest/-/releases) [![pipeline status](https://gitlab.com/OldIronHorse/squeeze-rest/badges/master/pipeline.svg)](https://gitlab.com/OldIronHorse/squeeze-rest/-/commits/master) [![coverage report](https://gitlab.com/OldIronHorse/squeeze-rest/badges/master/coverage.svg)](https://gitlab.com/OldIronHorse/squeeze-rest/-/commits/master) 

This ReST API wraps the Logitech Media Server/SqueezeBox API.
